blockSize constant
int
const blockSize
Bytes in one block, which is also the length readBlock returns and writeBlock wants.
Implementation
static const int blockSize = 16;
Bytes in one block, which is also the length readBlock returns and writeBlock wants.
static const int blockSize = 16;