increment method
Adds to a value block, leaving the result in the internal transfer buffer.
Implementation
Future<void> increment({required int blockIndex, required int value}) =>
androidApi.mifareClassicIncrement(_handle, blockIndex, value);
Adds to a value block, leaving the result in the internal transfer buffer.
Future<void> increment({required int blockIndex, required int value}) =>
androidApi.mifareClassicIncrement(_handle, blockIndex, value);