from static method
Returns an instance for tag, or null when the tag cannot be NDEF-formatted.
Implementation
static NdefFormatable? from(NfcTag tag) => tag.data.ndefFormatable == true ? NdefFormatable._(tag.data.handle) : null;
Returns an instance for tag, or null when the tag cannot be NDEF-formatted.
static NdefFormatable? from(NfcTag tag) => tag.data.ndefFormatable == true ? NdefFormatable._(tag.data.handle) : null;