deviceFoldable property

bool deviceFoldable
final

True for a foldable, where antennas describes the device unfolded and an antenna can therefore be on either half.

Implementation

final bool deviceFoldable;