isTagIntentAllowed method

Future<bool> isTagIntentAllowed()

Whether the user has allowed this app to be launched by a tag.

True on a device with no allowlist, so false always means the user actually said no -- which they can be asked to undo with openTagIntentPreferenceSettings.

Implementation

Future<bool> isTagIntentAllowed() => androidApi.isTagIntentAllowed();