isHealthy property
bool
get
isHealthy
True when nothing found here would stop a tap from reaching the app.
Implementation
bool get isHealthy => tagIntentAllowed && unguardedActivities.isEmpty;
True when nothing found here would stop a tap from reaching the app.
bool get isHealthy => tagIntentAllowed && unguardedActivities.isEmpty;