tagIntentAllowed property

bool get tagIntentAllowed

Whether the user has this app on Android 16's tag-scan allowlist. True on a device with no such allowlist, so that "false" always means the user actually said no.

Implementation

bool get tagIntentAllowed => _data.tagIntentAllowed;