sendCommand method

Future<Iso7816ResponseApdu> sendCommand(
  1. CommandApdu command
)

Sends command, following any chain it starts.

The payload of every frame is concatenated, and the status word returned is the last one -- the one that ended the chain rather than the 61xx that continued it.

Throws a StateError when the card asks for more than maxContinuations continuations.

Implementation

Future<Iso7816ResponseApdu> sendCommand(CommandApdu command) =>
    _chain(command.toBytes(), (length) => command.withExpectedResponseLength(length).toBytes());