FeliCaPollingResponse class

The answer to a FeliCa polling command.

Constructors

FeliCaPollingResponse({required Uint8List manufacturerParameter, required Uint8List requestData})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
manufacturerParameter Uint8List
The card's manufacture parameter, PMm.
final
requestData Uint8List
The data the request code asked for. Empty when the polling used FeliCaPollingRequestCode.noRequest.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited