FeliCaPollingTimeSlot enum

How many time slots a FeliCa polling command offers for answers.

Inheritance
Available extensions

Values

max1 → const FeliCaPollingTimeSlot
max2 → const FeliCaPollingTimeSlot
max4 → const FeliCaPollingTimeSlot
max8 → const FeliCaPollingTimeSlot
max16 → const FeliCaPollingTimeSlot

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FeliCaPollingTimeSlot>
A constant List of the values in this enum, in order of their declaration.