select method
Puts the tag in the selected state, so later commands need not carry its UID.
Implementation
Future<void> select({required Set<Iso15693RequestFlag> requestFlags}) =>
iosApi.iso15693Select(_handle, _flags(requestFlags));
Puts the tag in the selected state, so later commands need not carry its UID.
Future<void> select({required Set<Iso15693RequestFlag> requestFlags}) =>
iosApi.iso15693Select(_handle, _flags(requestFlags));