data property
The response with its flag byte stripped off. Empty when the tag answered with the flag alone.
Implementation
final Uint8List data;
The response with its flag byte stripped off. Empty when the tag answered with the flag alone.
final Uint8List data;