dataStorageFormatIdentifier property
The DSFID, an application-defined byte describing how the data is laid out.
Implementation
final int dataStorageFormatIdentifier;
The DSFID, an application-defined byte describing how the data is laid out.
final int dataStorageFormatIdentifier;