totalBlocks property
How many blocks the tag holds. Note this can exceed 255, in which case the block number arguments below cannot address them all -- the extended commands exist for that.
Implementation
final int totalBlocks;
How many blocks the tag holds. Note this can exceed 255, in which case the block number arguments below cannot address them all -- the extended commands exist for that.
final int totalBlocks;