VasResponse class

One wallet pass, or the reason there was none.

Constructors

VasResponse({required VasResponseErrorCode status, required Uint8List vasData, required Uint8List mobileToken})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mobileToken Uint8List
The token identifying the device that answered.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status VasResponseErrorCode
Whether the pass was returned, and if not, why not.
final
vasData Uint8List
The pass payload. Empty unless status is VasResponseErrorCode.success.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited