byteLength property
int
get
byteLength
The number of bytes this message occupies when stored on a tag.
Implementation
int get byteLength => records.fold(0, (sum, record) => sum + record.byteLength);
The number of bytes this message occupies when stored on a tag.
int get byteLength => records.fold(0, (sum, record) => sum + record.byteLength);