enableForegroundDispatch method

  1. @override
Future<void> enableForegroundDispatch()

Claims tag delivery while the activity is in the foreground, so a tag cannot be hijacked by another app's intent filter.

Implementation

@override
Future<void> enableForegroundDispatch() async {}