openNfcSettings method

  1. @override
Future<bool> openNfcSettings()

Opens the system NFC settings screen. False when there is no activity to start it from, or the device has no such screen.

Implementation

@override
Future<bool> openNfcSettings() async => false;