setDiscoveryTechnology method

  1. @override
Future<void> setDiscoveryTechnology(
  1. List<PollTechPigeon> poll,
  2. List<ListenTechPigeon> listen
)

Restricts what the controller polls for and answers as, for as long as the activity is in the foreground. API 35 and above.

Implementation

@override
Future<void> setDiscoveryTechnology(List<PollTechPigeon> poll, List<ListenTechPigeon> listen) async {}