FakeTech.felica constructor

FakeTech.felica({
  1. Uint8List? currentSystemCode,
  2. Uint8List? currentIDm,
})

NFCFeliCaTag. iOS only.

Both values default to zeroes of the length the real thing has, since a wrong length is the failure a test of FeliCa framing would want to catch and an invented value is not.

Implementation

factory FakeTech.felica({Uint8List? currentSystemCode, Uint8List? currentIDm}) => FakeTech._(
  null,
  (data) => data.felica = FeliCaPigeon(
    currentSystemCode: currentSystemCode ?? Uint8List(2),
    currentIDm: currentIDm ?? Uint8List(8),
  ),
);