NfcEvent class
One card-emulation event from NfcUtilAndroid.onNfcEvent.
Which fields are set follows from kind; the rest are null.
Properties
- adapterState → NfcAdapterState?
-
The new adapter state, for NfcEventKind.nfcStateChanged.
no setter
- aid → String?
-
The AID, for NfcEventKind.aidConflictOccurred and NfcEventKind.aidNotRouted.
no setter
- enabled → bool?
-
Set for NfcEventKind.preferredServiceChanged (is this app preferred),
NfcEventKind.observeModeStateChanged (is observe mode on) and
NfcEventKind.remoteFieldChanged (is a reader's field present).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalError → NfcInternalError?
-
What went wrong, for NfcEventKind.internalError.
no setter
- kind → NfcEventKind
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited