NfcListenTech enum
A technology NfcUtilAndroid.setDiscoveryTechnology can listen as.
There is no NFC-V entry: Android offers passive listening for A, B and F only. See NfcPollTech for disable and keep.
Values
- nfcA → const NfcListenTech
- nfcB → const NfcListenTech
- nfcF → const NfcListenTech
- disable → const NfcListenTech
- keep → const NfcListenTech
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NfcListenTech> - A constant List of the values in this enum, in order of their declaration.