requestService method
Reads the key version of each node in nodeCodeList.
A key version of FFFF means the node does not exist on this card.
Implementation
Future<List<Uint8List>> requestService({required List<Uint8List> nodeCodeList}) =>
iosApi.felicaRequestService(_handle, nodeCodeList);