FeliCaRequestSpecificationVersionResponse class
The answer to a FeliCa request-specification-version command.
Constructors
- FeliCaRequestSpecificationVersionResponse({required int statusFlag1, required int statusFlag2, required Uint8List? basicVersion, required Uint8List? optionVersion})
-
const
Properties
- basicVersion → Uint8List?
-
The version of the card's basic specification. Null when it reported none.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- optionVersion → Uint8List?
-
The version of the card's optional specification. Null when it implements none.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusFlag1 → int
-
Status flag 1. Zero means the command succeeded.
final
- statusFlag2 → int
-
Status flag 2, which says why when statusFlag1 is non-zero.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited