queryStatus method
Re-reads the status and capacity from the tag.
status and capacity are a snapshot taken at discovery; this is the live pair, and
the way to confirm a tag actually locked after Ndef.writeLock().
Implementation
Future<QueryNdefStatusResponse> queryStatus() async {
final response = await iosApi.ndefQueryStatus(_handle);
return QueryNdefStatusResponse(status: ndefStatusFromWire(response.status), capacity: response.capacity);
}