VasResponseErrorCode enum
Why a VAS command did not return a pass.
Values
- success → const VasResponseErrorCode
-
The pass was returned.
- userIntervention → const VasResponseErrorCode
-
The user has to act on the device before the pass can be read.
- dataNotActivated → const VasResponseErrorCode
-
The pass exists but is not active.
- dataNotFound → const VasResponseErrorCode
-
No matching pass is installed.
- incorrectData → const VasResponseErrorCode
- unsupportedApplicationVersion → const VasResponseErrorCode
- wrongLcField → const VasResponseErrorCode
- wrongParameters → const VasResponseErrorCode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VasResponseErrorCode> - A constant List of the values in this enum, in order of their declaration.