openTagIntentPreferenceSettings method
Opens the system screen where the user changes that. False when there is no activity to start it from, or the device has no such screen.
Implementation
@override
Future<bool> openTagIntentPreferenceSettings() async => false;